package com.game.business.mapper;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.game.business.domain.AppUser;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

/**
 * app用户Mapper接口
 *
 * @author game
 * @date 2024-06-18
 */
public interface AppUserMapper extends BaseMapper<AppUser> {
    /**
     * 查询app用户
     *
     * @param userid app用户主键
     * @return app用户
     */
    public AppUser selectAppUserByUserid(Long userid);

    /**
     * 查询app用户列表
     *
     * @param appUser app用户
     * @return app用户集合
     */
    public List<AppUser> selectAppUserList(AppUser appUser);

    /**
     * 新增app用户
     *
     * @param appUser app用户
     * @return 结果
     */
    public int insertAppUser(AppUser appUser);

    /**
     * 修改app用户
     *
     * @param appUser app用户
     * @return 结果
     */
    public int updateAppUser(AppUser appUser);

    /**
     * 删除app用户
     *
     * @param userid app用户主键
     * @return 结果
     */
    public int deleteAppUserByUserid(Long userid);

    /**
     * 批量删除app用户
     *
     * @param userids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppUserByUserids(Long[] userids);

    Long nextId();

    @Select("select * from app_user where pid = 0 and agent_flag = 1")
    public List<AppUser> selectTeamUserList();

    /**
     * 更新用户钱包
     * */
    public int updateUserMoney(AppUser appUser);

    Map<String, BigDecimal> getUserCount(Long userId);
}